ToolError

Enum ToolError 

pub enum ToolError {
    Abort,
    Custom(String),
}
Returned by the tool in the final result() call as reason if no value was computed. It is seriazable since it is the only error that ist actually sent over the WebSocket connection.

Variants



Abort

This does not contain the abort reason because not all of them are seriazable. The server logs should have the abort with the reason logged.



Custom(String)