The structured types exist to give values that could be expressed with
[Dict]s and [List]s a known structure and meaning that tools / scripts
can rely on. The number of these types is kept low to improve reuseability.
They are useful to force tools / scripts to decide on one specific structure
and to increase compatibility. They also increase maintenance burden, which
means that for niche applications it is preferred that tool + script agree
on a structure and use dynamic types instead of extending the toolapi.
Modules
- atomic
- dynamic
- structured
- typed
- Contains [
List]s and [Dict]s where all values have the same type